@@ -13,7 +13,6 @@ use rustyline::highlight::{Highlighter, MatchingBracketHighlighter};
 use rustyline::hint::Hinter;
 use rustyline::line_buffer::LineBuffer;
 use rustyline::Context;
-use rustyline_derive::Helper;
 
 use unicode_segmentation::Graphemes;
 use unicode_segmentation::UnicodeSegmentation;
@@ -157,11 +156,7 @@ impl CompletionList {
     }
 
     pub fn selected(&self) -> Option<String> {
-        if let Some(i) = self.state.selected() {
-            self.get(i)
-        } else {
-            None
-        }
+        self.state.selected().and_then(|i| self.get(i))
     }
 
     pub fn is_empty(&self) -> bool {
